pub fn set_wallpaper(
images: &[FileInfo],
config: &Config,
env: &Environment<'_>,
) -> WallSwitchResult<()>Expand description
Set desktop wallpaper based on the detected Desktop Environment.
pub fn set_wallpaper(
images: &[FileInfo],
config: &Config,
env: &Environment<'_>,
) -> WallSwitchResult<()>Set desktop wallpaper based on the detected Desktop Environment.