pub struct GnomeBackend;Trait Implementations
Sourceimpl WallpaperBackend for GnomeBackend
impl WallpaperBackend for GnomeBackend
Sourcefn build_commands(
_images: &[FileInfo],
config: &Config,
) -> WallSwitchResult<Vec<Command>>
fn build_commands( _images: &[FileInfo], config: &Config, ) -> WallSwitchResult<Vec<Command>>
Generates the GSettings commands required to set the GNOME desktop background.
This method constructs the command execution vectors to update both picture-uri
(light style) and picture-uri-dark (dark style) keys inside the
org.gnome.desktop.background schema, as well as setting the rendering layout
to "spanned".
Errors
This function does not currently return an error under standard operation,
but returns a WallSwitchResult to comply with the WallpaperBackend trait.