list_json_cache

Function list_json_cache 

pub fn list_json_cache(
    state: &State,
    criteria: SortCriteria,
) -> WallSwitchResult<()>
Lists the internal state cache as a filtered JSON object.

This is useful for debugging the Smart Cache or for integration with external tools like ‘jq’.