Module core

Module core 

The pure Domain of the application. Contains all business rules, entities, and validation.

Structs

CacheEntry
Represents cached information of a file to prevent re-hashing and re-probing
Config
Configuration variables
CustomFractalPreset
A serialized custom Julia/Mandelbrot preset representing the focal point.
CustomNewtonPreset
A serialized custom Newton preset representing root-finding convergence fields.
CustomNovaPreset
A serialized custom Nova preset representing dynamic fluid-like plumes.
Dimension
Represents the physical dimensions (width and height) of an image.
EffectsConfig
Configurable parameters and custom presets for procedural mathematical overlays.
FileInfo
Image information representing a wallpaper candidate.
Monitor
Monitor properties
SliceDisplay
State
Manages the Wallpaper History and the Smart Cache

Enums

FileValidationError
Represents the explicit reasons why a candidate wallpaper file is invalid.
Orientation
Orientation: Horizontal or Vertical.

Traits

FileInfoExt

Functions

get_config_path
Config file path: “/home/user_name/.config/wallswitch/wallswitch.json”
get_directories
Default directories to search for images
get_monitors
Get N monitors
get_wallpaper_path
Default wallpaper path: “/home/user_name/wallswitch.jpg”
read_config_file
Read config file path: “/home/user_name/.config/wallswitch/wallswitch.json”

Type Aliases

FileValidationResult