pub struct ViewportSpecs {
pub center: Complex,
pub zoom: f64,
pub rotation: Complex,
pub is_julia: bool,
}Expand description
Parameters used to construct a Viewport from physical screen dimensions.
Fields
center: ComplexFocal complex centre point.
zoom: f64Zoom translation scaling index.
rotation: ComplexRotational coordinate transformation phasor.
is_julia: boolWhen true, the viewport maps around the origin (Julia-style).