pub fn list_json_cache(
state: &State,
criteria: SortCriteria,
) -> WallSwitchResult<()>Expand description
Lists the internal state cache as a filtered JSON object.
This is useful for debugging the Smart Cache or for integration with external tools like ‘jq’.