The pure Domain of the application. Contains all business rules, entities, and validation.
Structs
- Cache
Entry - Represents cached information of a file to prevent re-hashing and re-probing
- Config
- Configuration variables
- Custom
Fractal Preset - A serialized custom Julia/Mandelbrot preset representing the focal point.
- Custom
Newton Preset - A serialized custom Newton preset representing root-finding convergence fields.
- Custom
Nova Preset - A serialized custom Nova preset representing dynamic fluid-like plumes.
- Dimension
- Represents the physical dimensions (width and height) of an image.
- Effects
Config - Configurable parameters and custom presets for procedural mathematical overlays.
- File
Info - Image information representing a wallpaper candidate.
- Monitor
- Monitor properties
- Slice
Display - State
- Manages the Wallpaper History and the Smart Cache
Enums
- File
Validation Error - Represents the explicit reasons why a candidate wallpaper file is invalid.
- Orientation
- Orientation: Horizontal or Vertical.
Traits
Functions
- get_
config_ path - Config file path: “/home/user_name/.config/wallswitch/wallswitch.json”
- get_
directories - Default directories to search for images
- get_
monitors - Get N monitors
- get_
wallpaper_ path - Default wallpaper path: “/home/user_name/wallswitch.jpg”
- read_
config_ file - Read config file path: “/home/user_name/.config/wallswitch/wallswitch.json”